contextkeys

package
v1.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 19, 2024 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package contextkeys stores the keys to the context accessor functions, letting generated code safely set values in contexts without exposing the setters to the outside world.

Index

Constants

const (
	Account = KeyString("X-Account-ID")
	User    = KeyString("X-User-ID")

	TokenPointer = KeyString("tokenPointer")
)

Added useful keys

Variables

This section is empty.

Functions

This section is empty.

Types

type KeyString

type KeyString string

KeyString should be used when setting and fetching context values

Jump to